==> transientNamer-0.4.0.tar.gz: transientNamer-0.4.0/transientNamer/tests/output/3d_since_20210125_tns_conesearch_relatedFiles.md <==
| TNSId     | filename                                                             | url                                                                                                                           | dateObs              | spec1phot2  |
|:----------|:---------------------------------------------------------------------|:------------------------------------------------------------------------------------------------------------------------------|:---------------------|:------------|
| 2021avg   | tns_2021avg_2459239.627795336_NOT_ALFOSC_ZTF.ascii                   | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021avg_2459239.627795336_NOT_ALFOSC_ZTF.ascii                          | 2021-01-25 03:04:02  | 1           |
| 2021aul   | tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | 2021-01-20 04:02:46  | 1           |
| 2021aul   | tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | 2021-01-20 04:02:46  | 1           |
| 2021aqq   | tns_2021aqq_2021-01-18.404_Lick-3m_KAST_SIRAH.flm                    | https://www.wis-tns.org/system/files/uploaded/SIRAH/tns_2021aqq_2021-01-18.404_Lick-3m_KAST_SIRAH.flm                         | 2021-01-18 09:41:46  | 1           |
| 2021apd   | tns_2021apd_2021-01-18_NOT_ALFOSC_YSE.csv                            | https://www.wis-tns.org/system/files/uploaded/YSE/tns_2021apd_2021-01-18_NOT_ALFOSC_YSE.csv                                   | 2021-01-18 00:00:00  | 1           |
| 2021yk    | tns_2021yk_2021-01-14_10-20-54_UH88_SNIFS_SCAT.dat                   | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2021yk_2021-01-14_10-20-54_UH88_SNIFS_SCAT.dat                         | 2021-01-14 10:20:54  | 1           |
| 2021xv    | tns_2021xv_2459239.7189359954_NOT_ALFOSC_ZTF.ascii                   | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021xv_2459239.7189359954_NOT_ALFOSC_ZTF.ascii                          | 2021-01-25 05:15:16  | 1           |
| 2021gl    | tns_2021gl_2021-01-06_07-33-52.115795_P60_SEDM_ZTF.ascii             | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021gl_2021-01-06_07-33-52.115795_P60_SEDM_ZTF.ascii                    | 2021-01-06 07:33:52  | 1           |
| 2021ab    | tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci    | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci    | 2021-01-08 06:18:47  | 1           |
| 2021ab    | tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits    | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits    | 2021-01-08 06:18:47  | 1           |
| 2021G     | tns_2021G_2459220.0019_UH88_SNIFS_SCAT.dat                           | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2021G_2459220.0019_UH88_SNIFS_SCAT.dat                                 | 2021-01-05 12:02:44  | 1           |
| 2020aeuv  | tns_2020aeuv_2459239.653425347_NOT_ALFOSC_ZTF.ascii                  | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020aeuv_2459239.653425347_NOT_ALFOSC_ZTF.ascii                         | 2021-01-25 03:40:56  | 1           |
| 2020aeqo  | tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | 2021-01-02 03:11:41  | 1           |
| 2020aeqo  | tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | 2021-01-02 03:11:41  | 1           |
| 2020adlp  | tns_2020adlp_2021-01-02_05-46-19.143271_P60_SEDM_ZTF.ascii           | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020adlp_2021-01-02_05-46-19.143271_P60_SEDM_ZTF.ascii                  | 2021-01-02 05:46:19  | 1           |
| 2020adbk  | tns_2020adbk_2021-01-04_07-38-16.472752_P60_SEDM_ZTF.ascii           | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020adbk_2021-01-04_07-38-16.472752_P60_SEDM_ZTF.ascii                  | 2021-01-04 07:38:16  | 1           |
| 2020acma  | tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | 2020-12-15 06:31:22  | 1           |
| 2020acma  | tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | 2020-12-15 06:31:22  | 1           |
| 2020acew  | tns_2020acew_2021-01-08_00-00-00_P200_DBSP_ZTF.ascii                 | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020acew_2021-01-08_00-00-00_P200_DBSP_ZTF.ascii                        | 2021-01-08 00:00:00  | 1           |
| 2020zko   | tns_2020zko_2459168.1248_UH88_SNIFS_SCAT.dat                         | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2020zko_2459168.1248_UH88_SNIFS_SCAT.dat                               | 2020-11-14 14:59:43  | 1           |
| 2020ytk   | tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | 2020-11-10 02:20:42  | 1           |
| 2020ytk   | tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | 2020-11-10 02:20:42  | 1           |
| 2020pub   | tns_2020pub_2020-12-15_12-01-30.339432_P60_SEDM_ZTF.ascii            | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020pub_2020-12-15_12-01-30.339432_P60_SEDM_ZTF.ascii                   | 2020-12-15 12:01:30  | 1           |

==> transientNamer-0.4.1.tar.gz: transientNamer-0.4.1/transientNamer/tests/output/3d_since_20210125_tns_conesearch_relatedFiles.md <==
| TNSId     | filename                                                             | url                                                                                                                           | dateObs              | spec1phot2  |
|:----------|:---------------------------------------------------------------------|:------------------------------------------------------------------------------------------------------------------------------|:---------------------|:------------|
| 2021avg   | tns_2021avg_2459239.627795336_NOT_ALFOSC_ZTF.ascii                   | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021avg_2459239.627795336_NOT_ALFOSC_ZTF.ascii                          | 2021-01-25 03:04:02  | 1           |
| 2021aul   | tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | 2021-01-20 04:02:46  | 1           |
| 2021aul   | tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021aul_2021-01-20_04-02-46_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | 2021-01-20 04:02:46  | 1           |
| 2021aqq   | tns_2021aqq_2021-01-18.404_Lick-3m_KAST_SIRAH.flm                    | https://www.wis-tns.org/system/files/uploaded/SIRAH/tns_2021aqq_2021-01-18.404_Lick-3m_KAST_SIRAH.flm                         | 2021-01-18 09:41:46  | 1           |
| 2021apd   | tns_2021apd_2021-01-18_NOT_ALFOSC_YSE.csv                            | https://www.wis-tns.org/system/files/uploaded/YSE/tns_2021apd_2021-01-18_NOT_ALFOSC_YSE.csv                                   | 2021-01-18 00:00:00  | 1           |
| 2021ajy   | tns_2021ajy_2021-01-15_11-44-14.027454_P60_SEDM_ZTF.ascii            | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021ajy_2021-01-15_11-44-14.027454_P60_SEDM_ZTF.ascii                   | 2021-01-15 11:44:14  | 1           |
| 2021yk    | tns_2021yk_2021-01-14_10-20-54_UH88_SNIFS_SCAT.dat                   | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2021yk_2021-01-14_10-20-54_UH88_SNIFS_SCAT.dat                         | 2021-01-14 10:20:54  | 1           |
| 2021xv    | tns_2021xv_2459239.7189359954_NOT_ALFOSC_ZTF.ascii                   | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021xv_2459239.7189359954_NOT_ALFOSC_ZTF.ascii                          | 2021-01-25 05:15:16  | 1           |
| 2021gl    | tns_2021gl_2021-01-06_07-33-52.115795_P60_SEDM_ZTF.ascii             | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021gl_2021-01-06_07-33-52.115795_P60_SEDM_ZTF.ascii                    | 2021-01-06 07:33:52  | 1           |
| 2021fg    | tns_2021fg_2021-01-14_07-13-53.199279_P60_SEDM_ZTF.ascii             | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2021fg_2021-01-14_07-13-53.199279_P60_SEDM_ZTF.ascii                    | 2021-01-14 07:13:53  | 1           |
| 2021at    | tns_2021at_2021-01-11_Lick-3m_KAST_UCSC.flm                          | https://www.wis-tns.org/system/files/uploaded/UCSC/tns_2021at_2021-01-11_Lick-3m_KAST_UCSC.flm                                | 2021-01-11 00:00:00  | 1           |
| 2021ab    | tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci    | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci    | 2021-01-08 06:18:47  | 1           |
| 2021ab    | tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits    | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2021ab_2021-01-08_06-18-47_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits    | 2021-01-08 06:18:47  | 1           |
| 2021G     | tns_2021G_2459220.0019_UH88_SNIFS_SCAT.dat                           | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2021G_2459220.0019_UH88_SNIFS_SCAT.dat                                 | 2021-01-05 12:02:44  | 1           |
| 2020aeuv  | tns_2020aeuv_2459239.653425347_NOT_ALFOSC_ZTF.ascii                  | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020aeuv_2459239.653425347_NOT_ALFOSC_ZTF.ascii                         | 2021-01-25 03:40:56  | 1           |
| 2020aeqp  | tns_2020aeqp_2021-01-11_Lick-3m_KAST_UCSC.flm                        | https://www.wis-tns.org/system/files/uploaded/UCSC/tns_2020aeqp_2021-01-11_Lick-3m_KAST_UCSC.flm                              | 2021-01-11 00:00:00  | 1           |
| 2020aeqo  | tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | 2021-01-02 03:11:41  | 1           |
| 2020aeqo  | tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020aeqo_2021-01-02_03-11-41_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | 2021-01-02 03:11:41  | 1           |
| 2020adlp  | tns_2020adlp_2021-01-02_05-46-19.143271_P60_SEDM_ZTF.ascii           | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020adlp_2021-01-02_05-46-19.143271_P60_SEDM_ZTF.ascii                  | 2021-01-02 05:46:19  | 1           |
| 2020adbk  | tns_2020adbk_2021-01-04_07-38-16.472752_P60_SEDM_ZTF.ascii           | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020adbk_2021-01-04_07-38-16.472752_P60_SEDM_ZTF.ascii                  | 2021-01-04 07:38:16  | 1           |
| 2020acma  | tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci  | 2020-12-15 06:31:22  | 1           |
| 2020acma  | tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020acma_2020-12-15_06-31-22_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits  | 2020-12-15 06:31:22  | 1           |
| 2020acew  | tns_2020acew_2021-01-08_00-00-00_P200_DBSP_ZTF.ascii                 | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020acew_2021-01-08_00-00-00_P200_DBSP_ZTF.ascii                        | 2021-01-08 00:00:00  | 1           |
| 2020zko   | tns_2020zko_2459168.1248_UH88_SNIFS_SCAT.dat                         | https://www.wis-tns.org/system/files/uploaded/SCAT/tns_2020zko_2459168.1248_UH88_SNIFS_SCAT.dat                               | 2020-11-14 14:59:43  | 1           |
| 2020ytk   | tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.asci   | 2020-11-10 02:20:42  | 1           |
| 2020ytk   | tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | https://www.wis-tns.org/system/files/uploaded/ePESSTO%2B/tns_2020ytk_2020-11-10_02-20-42_ESO-NTT_EFOSC2-NTT_ePESSTO%2B.fits   | 2020-11-10 02:20:42  | 1           |
| 2020xba   | tns_2020xba_2020-10-18_10-22-36_P60_SEDM_ZTF.ascii                   | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020xba_2020-10-18_10-22-36_P60_SEDM_ZTF.ascii                          | 2020-10-18 10:22:36  | 1           |
| 2020pub   | tns_2020pub_2020-12-15_12-01-30.339432_P60_SEDM_ZTF.ascii            | https://www.wis-tns.org/system/files/uploaded/ZTF/tns_2020pub_2020-12-15_12-01-30.339432_P60_SEDM_ZTF.ascii                   | 2020-12-15 12:01:30  | 1           |
